////////////////////////////////////////////////////////////////////////////////
// File      : HVProbe.h
// Function  : Include file for applications using CPS high voltage USB probes
// System    : Operating system independent
// Author    : Jim Lamberson
// Copyright : (C) CPS, 2015
////////////////////////////////////////////////////////////////////////////////

#ifndef _INC_PROBE_API_H_
#define _INC_PROBE_API_H_

// Constants ----------------------------------------------

#define MAX_NUM_PROBES          16              // Maximum number of probes supported by API

// API error codes
#define HVP_ERR_OK              0               // No errors
#define HVP_ERR_DEVICE_MALLOC   (-1)            // Insufficient memory
#define HVP_ERR_DEVICE_OPEN     (-2)            // Error reading device info
#define HVP_ERR_READ_OPEN       (-3)            // Can't open device for reading
#define HVP_ERR_WRITE_OPEN      (-4)            // Can't open device for writing
#define HVP_ERR_READ            (-5)            // Error reading device
#define HVP_ERR_WRITE           (-6)            // Error writing device
#define HVP_ERR_PROBE_ID        (-7)            // Invalid probe number
#define HVP_ERR_CHECKSUM        (-8)            // Invalid calibration and serial number
#define HVP_ERR_PROBE_CLOSED    (-9)            // Probe is not open
#define HVP_ERR_DEVICE_PARAM    (-10)           // Unexpected device parameter

// Bit masks for status value returned by HVP_GetStatus()
#define HVP_STATUS_ALARM        0x00000001      // HV proximity detected while probe ground lead is floating

// Types -------------------------------------------------

typedef enum METER_ID {         // METER IDENTIFIERS --------
    METER_DC,                   //   DC meter
    METER_AC,                   //   AC meter
    METER_MIN,                  //   DC minimum peak detector
    METER_MAX,                  //   DC maximum peak detector
    METER_T,                    //   Probe internal temperature
    NUM_METERS
} METER_ID;

typedef struct PROBE_INFO {     // PROBE ATTRIBUTES -------
    int model;                  //   Model number
    int version;                //   Firmware version
    int serialnum;              //   Serial number
    double vscale_dc;           //   Scale of DC meters
    double vscale_ac;           //   Scale of AC meter
    char firmware_info[128];    //   Firmware info string
} PROBE_INFO;

// API functions -----------------------------------------

#ifdef _WIN32
#   ifdef BUILD_API
#       define APIFUNC __declspec(dllexport)
#   else
#       define APIFUNC
#   endif
#   define CCONV __stdcall
#else
#   define CCONV
#   define APIFUNC
#endif

#ifdef __cplusplus
extern "C" {
#endif

// User functions
APIFUNC int CCONV HVP_OpenSystem(void);                                     // THIS MUST BE CALLED FIRST. Enumerate and enable access to all probes. Returns error or number of detected probes.
APIFUNC int CCONV HVP_CloseSystem(void);                                    // THIS MUST BE CALLED LAST. Close all probes and free all API resources.
APIFUNC int CCONV HVP_OpenProbe(int ProbeID);                               // Open a probe to allow communication with it. THIS MUST BE CALLED BEFORE COMMUNICATING WITH A PROBE.
APIFUNC int CCONV HVP_CloseProbe(int ProbeID);                              // Close a probe. Further communication with the probe is not allowed.
APIFUNC int CCONV HVP_GetAttributes(int ProbeID, PROBE_INFO *info);         // Get attributes of an open probe.
APIFUNC int CCONV HVP_GetStatus(int ProbeID, int *status);                  // Get status bits from an open probe.
APIFUNC int CCONV HVP_GetMeters(int ProbeID, double buf[NUM_METERS]);       // Get meter data from an open probe.
APIFUNC char* CCONV HVP_ErrorString(int errcode);                           // Convert error code to descriptive string.
APIFUNC int CCONV HVP_GetApiVersion(void);                                  // Get API version numbers.

// Diagnostic functions
APIFUNC int CCONV HVP_GetRawMeters(int ProbeID, double buf[NUM_METERS]);    // Get uncorrected meter data from an open probe.
APIFUNC int CCONV HVP_ReadEeprom(int ProbeID, unsigned char *buf);          // Read EEPROM contents from an open probe.
APIFUNC int CCONV HVP_WriteEeprom(int ProbeID, unsigned char *eebuf);       // Write EEPROM contents to an open probe (checksum is automatically computed and inserted).

#ifdef __cplusplus
}
#endif


#endif // ifndef _INC_PROBE_API_H_
